@@ -1,11 +1,10 @@
 use strict;
 use warnings;
-use 5.006;
+use 5.024;
 
 package App::Cmd;
-$App::Cmd::VERSION = '0.329';
-use App::Cmd::ArgProcessor;
-BEGIN { our @ISA = 'App::Cmd::ArgProcessor' };
+$App::Cmd::VERSION = '0.332';
+use parent 'App::Cmd::ArgProcessor';
 # ABSTRACT: write command line apps with less suffering
 
 use File::Basename ();
@@ -47,7 +46,7 @@ sub _setup_command {
 }
 
 sub _setup_ignore {
-  my ($self, $val, $data ) = @_;
+  my ($self, $val, $data) = @_;
   my $into = $data->{into};
 
   Carp::confess "App::Cmd -ignore setup requested for already-setup class"
@@ -165,13 +164,16 @@ sub new {
   my $base = File::Basename::basename $arg0;
 
   my $self = {
-    command      => $class->_command($arg),
     arg0         => $base,
     full_arg0    => $arg0,
-    show_version => $arg->{show_version_cmd} || 0,
+    show_version => $arg->{show_version_cmd} // 0,
   };
 
-  bless $self => $class;
+  bless $self, $class;
+
+  $self->{command} = $self->_command($arg);
+
+  return $self;
 }
 
 # effectively, returns the command-to-plugin mapping guts of a Cmd
@@ -186,7 +188,7 @@ sub _command {
   #
   #  my $want_isa = $self->_default_command_base;
   # -- kentnl, 2010-12
-   my $want_isa = 'App::Cmd::Command';
+  my $want_isa = 'App::Cmd::Command';
 
   my %plugin;
   for my $plugin ($self->_plugins) {
@@ -233,7 +235,7 @@ sub _plugins {
   my ($self) = @_;
   my $class = ref $self || $self;
 
-  return @{ $plugins_for{$class} } if $plugins_for{$class};
+  return $plugins_for{$class}->@* if $plugins_for{$class};
 
   my $finder = Module::Pluggable::Object->new(
     search_path => $self->plugin_search_path,
@@ -251,16 +253,16 @@ sub _register_command {
   $self->_plugins;
 
   my $class = ref $self || $self;
-  push @{ $plugins_for{ $class } }, $cmd_class
-    unless grep { $_ eq $cmd_class } @{ $plugins_for{ $class } };
+  push $plugins_for{ $class }->@*, $cmd_class
+    unless grep { $_ eq $cmd_class } $plugins_for{ $class }->@*;
 }
 
 my %ignored_for;
 
 sub should_ignore {
-  my ( $self , $cmd_class ) = @_;
+  my ($self, $cmd_class) = @_;
   my $class = ref $self || $self;
-  for ( @{ $ignored_for{ $class } } ) {
+  for ($ignored_for{ $class }->@*) {
     return 1 if $_ eq $cmd_class;
   }
   return;
@@ -269,8 +271,8 @@ sub should_ignore {
 sub _register_ignore {
   my ($self, $cmd_class) = @_;
   my $class = ref $self || $self;
-  push @{ $ignored_for{ $class } }, $cmd_class
-    unless grep { $_ eq $cmd_class } @{ $ignored_for{ $class } };
+  push $ignored_for{ $class }->@*, $cmd_class
+    unless grep { $_ eq $cmd_class } $ignored_for{ $class }->@*;
 }
 
 sub _module_pluggable_options {
@@ -286,7 +288,7 @@ sub _load_default_plugin {
     my $plugin = "App::Cmd::Command::$plugin_name";
     Class::Load::load_class($plugin);
     for my $command (map { lc } $plugin->command_names) {
-      $plugin_href->{$command} ||= $plugin;
+      $plugin_href->{$command} //= $plugin;
     }
   }
 }
@@ -332,7 +334,7 @@ sub prepare_args {
   my ($self) = @_;
   return scalar(@ARGV)
     ? (@ARGV)
-    : (@{$self->default_args});
+    : ($self->default_args->@*);
 }
 
 #pod =method default_args
@@ -502,7 +504,7 @@ sub plugin_search_path {
   my @default = ($ccb, $self->_default_plugin_base);
 
   if (ref $self) {
-    return $self->{plugin_search_path} ||= \@default;
+    return $self->{plugin_search_path} //= \@default;
   } else {
     return \@default;
   }
@@ -536,7 +538,7 @@ sub allow_any_unambiguous_abbrev { return 0 }
 
 sub global_options {
 	my $self = shift;
-	return $self->{global_options} ||= {} if ref $self;
+	return $self->{global_options} //= {} if ref $self;
   return {};
 }
 
@@ -563,7 +565,7 @@ sub set_global_options {
 
 sub command_names {
   my ($self) = @_;
-  keys %{ $self->_command };
+  keys $self->_command->%*;
 }
 
 #pod =method command_groups
@@ -591,7 +593,7 @@ sub command_groups { }
 
 sub command_plugins {
   my ($self) = @_;
-  my %seen = map {; $_ => 1 } values %{ $self->_command };
+  my %seen = map {; $_ => 1 } values $self->_command->%*;
   keys %seen;
 }
 
@@ -691,7 +693,9 @@ sub global_opt_spec {
   my ($self) = @_;
 
   my $cmd = $self->{command};
-  my @help = reverse sort map { s/^--?//; $_ }
+  my %seen;
+  my @help = grep { ! $seen{$_}++ }
+             reverse sort map { s/^--?//; $_ }
              grep { $cmd->{$_} eq 'App::Cmd::Command::help' } keys %$cmd;
 
   return (@help ? [ join('|', @help) => "show help" ] : ());
@@ -740,7 +744,7 @@ App::Cmd - write command line apps with less suffering
 
 =head1 VERSION
 
-version 0.329
+version 0.332
 
 =head1 SYNOPSIS
 
@@ -1042,7 +1046,7 @@ Ricardo Signes <rjbs@cpan.org>
 
 =head1 CONTRIBUTORS
 
-=for stopwords Adam Prime ambs Andreas Hernitscheck A. Sinan Unur Chris 'BinGOs' Williams David Golden Steinbrunner Denis Ibaev Diab Jerius Glenn Fowler Ingy dot Net Jakob Voss Jérôme Quelin John SJ Anderson Karen Etheridge Kent Fredric Matthew Astley mokko Olivier Mengué Ricardo SIGNES Ryan C. Thompson Salvatore Bonaccorso Sergey Romanov Stephen Caldwell Yuval Kogman
+=for stopwords Adam Prime ambs Andreas Hernitscheck A. Sinan Unur Chris 'BinGOs' Williams David Golden Steinbrunner Davor Cubranic Denis Ibaev Diab Jerius Glenn Fowler Ingy dot Net Jakob Voss Jérôme Quelin John SJ Anderson Karen Etheridge Kent Fredric Lucas Theisen Matthew Astley mokko Olivier Mengué Ricardo Signes Ryan C. Thompson Salvatore Bonaccorso Sergey Romanov Stephan Loyd Stephen Caldwell Yuval Kogman
 
 =over 4
 
@@ -1076,6 +1080,10 @@ David Steinbrunner <dsteinbrunner@pobox.com>
 
 =item *
 
+Davor Cubranic <cubranic@stat.ubc.ca>
+
+=item *
+
 Denis Ibaev <dionys@gmail.com>
 
 =item *
@@ -1116,6 +1124,10 @@ Kent Fredric <kentfredric@gmail.com>
 
 =item *
 
+Lucas Theisen <ltheisen@mitre.org>
+
+=item *
+
 Matthew Astley <mca@sanger.ac.uk>
 
 =item *
@@ -1128,7 +1140,7 @@ Olivier Mengué <dolmen@cpan.org>
 
 =item *
 
-Ricardo SIGNES <rjbs@codesimply.com>
+Ricardo Signes <rjbs@semiotic.systems>
 
 =item *
 
@@ -1144,6 +1156,10 @@ Sergey Romanov <sromanov-dev@yandex.ru>
 
 =item *
 
+Stephan Loyd <stephanloyd9@gmail.com>
+
+=item *
+
 Stephen Caldwell <steve@campusexplorer.com>
 
 =item *
@@ -1154,7 +1170,7 @@ Yuval Kogman <nuffin@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by Ricardo Signes.
+This software is copyright (c) 2021 by Ricardo Signes.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
