@@ -2,7 +2,7 @@ use strict;
 use warnings;
 
 package App::Cmd::Simple;
-$App::Cmd::Simple::VERSION = '0.329';
+$App::Cmd::Simple::VERSION = '0.332';
 use App::Cmd::Command;
 BEGIN { our @ISA = 'App::Cmd::Command' }
 
@@ -21,7 +21,7 @@ use Sub::Install;
 #pod in F<YourApp/Cmd.pm>:
 #pod
 #pod   package YourApp::Cmd;
-#pod   use base qw(App::Cmd::Simple);
+#pod   use parent qw(App::Cmd::Simple);
 #pod
 #pod   sub opt_spec {
 #pod     return (
@@ -67,6 +67,17 @@ use Sub::Install;
 #pod
 #pod If not overridden, it returns an empty list.
 #pod
+#pod =head2 usage_desc
+#pod
+#pod This method should be overridden to provide the top level usage line.
+#pod It's a one-line summary of how the command is to be invoked, and
+#pod should be given in the format used for the C<$usage_desc> parameter to
+#pod C<describe_options> in Getopt::Long::Descriptive.
+#pod
+#pod If not overriden, it returns something that prints out like:
+#pod
+#pod   yourapp [-?h] [long options...]
+#pod
 #pod =head2 validate_args
 #pod
 #pod   $cmd->validate_args(\%opt, \@args);
@@ -213,7 +224,7 @@ App::Cmd::Simple - a helper for building one-command App::Cmd applications
 
 =head1 VERSION
 
-version 0.329
+version 0.332
 
 =head1 SYNOPSIS
 
@@ -225,7 +236,7 @@ in F<simplecmd>:
 in F<YourApp/Cmd.pm>:
 
   package YourApp::Cmd;
-  use base qw(App::Cmd::Simple);
+  use parent qw(App::Cmd::Simple);
 
   sub opt_spec {
     return (
@@ -271,6 +282,17 @@ after the first.)
 
 If not overridden, it returns an empty list.
 
+=head2 usage_desc
+
+This method should be overridden to provide the top level usage line.
+It's a one-line summary of how the command is to be invoked, and
+should be given in the format used for the C<$usage_desc> parameter to
+C<describe_options> in Getopt::Long::Descriptive.
+
+If not overriden, it returns something that prints out like:
+
+  yourapp [-?h] [long options...]
+
 =head2 validate_args
 
   $cmd->validate_args(\%opt, \@args);
@@ -313,7 +335,7 @@ Ricardo Signes <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by Ricardo Signes.
+This software is copyright (c) 2021 by Ricardo Signes.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
