@@ -2,7 +2,7 @@ use strict;
 use warnings;
 
 package App::Cmd::Subdispatch;
-$App::Cmd::Subdispatch::VERSION = '0.329';
+$App::Cmd::Subdispatch::VERSION = '0.332';
 use App::Cmd;
 use App::Cmd::Command;
 BEGIN { our @ISA = qw(App::Cmd::Command App::Cmd) } 
@@ -88,7 +88,7 @@ sub choose_parent_app {
 	if (
     $plugin->isa("App::Cmd::Command::commands")
     or $plugin->isa("App::Cmd::Command::help")
-    or scalar keys %{ $self->global_options }
+    or keys $self->global_options->%*
   ) {
 		return $self;
 	} else {
@@ -110,7 +110,7 @@ App::Cmd::Subdispatch - an App::Cmd::Command that is also an App::Cmd
 
 =head1 VERSION
 
-version 0.329
+version 0.332
 
 =head1 METHODS
 
@@ -148,7 +148,7 @@ Ricardo Signes <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by Ricardo Signes.
+This software is copyright (c) 2021 by Ricardo Signes.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
